"""Module that contains simple iterable utilities."""

import itertools

from typing import Any, Iterable, Iterator


def chunked_it(iterable: Iterable[Any], n: int) -> Iterator[itertools.chain[Any]]:
    """Splits an iterable into iterator chunks of length n. The last chunk may be shorter."""
    if n < 1:
        raise ValueError("n must be at least one")

    it = iter(iterable)
    for x in it:
        yield itertools.chain((x,), itertools.islice(it, n - 1))



"""Module that contains simple IO utilities."""

import json

from pathlib import Path
from typing import Any

import yaml


def yaml_load(filename: str, **kwargs: Any) -> Any:
    """Loads YAML file from filesystem."""
    with Path(filename).open("r") as f:
        return yaml.safe_load(f, **kwargs)


def yaml_save(path: str, data: dict[str, Any], **kwargs: Any) -> None:
    """Saves dictionary to YAML file."""
    with open(path, "w") as outfile:
        yaml.dump(data, outfile, default_flow_style=False, **kwargs)


def json_load(path: str, **kwargs: Any) -> Any:
    """Loads JSON file from filesystem."""
    with open(path) as f:
        return json.load(f, **kwargs)
